@@ -6,6 +6,9 @@ import typing as t
 
 from typing_extensions import Final, Literal
 
+from ._type_helpers import SupportsLessThan as _SupportsLessThan
+from ._type_helpers import SupportsGreaterOrEqual as _SupportsGreaterOrEqual
+
 if t.TYPE_CHECKING:  # pragma: no cover
     # pylint: disable=unused-import,invalid-name
     from ._maybe import Maybe
@@ -13,6 +16,7 @@ if t.TYPE_CHECKING:  # pragma: no cover
 _T = t.TypeVar('_T', covariant=True)
 _TT = t.TypeVar('_TT', covariant=True)
 _Y = t.TypeVar('_Y')
+_Z = t.TypeVar('_Z')
 
 
 class Just(t.Generic[_T]):
@@ -70,7 +74,10 @@ class Just(t.Generic[_T]):
         return chainer(self.value)
 
     def __repr__(self) -> str:
-        return f'Just({self.value})'
+        return f'Just({self.value!r})'
+
+    def __structlog__(self) -> t.Mapping[str, object]:
+        return {'type': 'Just', 'value': self.value}
 
     def alt(self, _alternative: 'Maybe[_T]') -> 'Maybe[_T]':
         """Return the given ``alternative`` if called on a ``Nothing``,
@@ -131,6 +138,17 @@ class Just(t.Generic[_T]):
         """
         return self.value
 
+    def or_none(self) -> _T:
+        """Get the value from a ``Just``, or ``None``.
+
+        >>> from ._nothing import Nothing
+        >>> Just(5).or_none()
+        5
+        >>> Nothing.or_none() is None
+        True
+        """
+        return self.value
+
     def case_of(
         self,
         *,
@@ -199,5 +217,58 @@ class Just(t.Generic[_T]):
         """
         return self.value
 
-    def __bool__(self) -> t.NoReturn:
+    def __bool__(self) -> Literal[False]:
         raise Exception('Do not check Just for boolean value')
+
+    def attr(self, attr: str) -> object:
+        """Get the given attribute from the value in the just and wrap the
+        result in a just.
+
+        This means that ``value.attr('attr')`` is equal to
+        ``value.map(lambda v: v.attr)``.
+        """
+        return Just(getattr(self.value, attr))
+
+    def join(self: 'Just[Maybe[_Y]]') -> 'Maybe[_Y]':
+        """Join a ``Just`` of a ``Maybe``.
+
+        This is equal to ``maybe.chain(x => x)``.
+        """
+        return self.value
+
+    def eq(self: 'Just[_Y]', val: _Y) -> bool:
+        """Check if a value of a ``Just`` is equal to the given value.
+        """
+        return self.value == val
+
+    def lt(  # pylint: disable=invalid-name
+        self: 'Just[_SupportsLessThan[_T]]',
+        val: _SupportsLessThan[_T],
+    ) -> bool:
+        """Check if a value of a ``Just`` is less than the given value.
+        """
+        return self.value < val
+
+    def le(
+        self: 'Just[_SupportsGreaterOrEqual[_T]]',
+        val: _SupportsGreaterOrEqual[_T],
+    ) -> bool:
+        """Check if a value of a ``Just`` is <= to the given value.
+        """
+        return self.value <= val
+
+    def gt(  # pylint: disable=invalid-name
+        self: 'Just[_SupportsLessThan[_T]]',
+        val: _SupportsLessThan[_T],
+    ) -> bool:
+        """Check if a value of a ``Just`` is > to the given value.
+        """
+        return self.value > val
+
+    def ge(
+        self: 'Just[_SupportsGreaterOrEqual[_T]]',
+        val: _SupportsGreaterOrEqual[_T],
+    ) -> bool:
+        """Check if a value of a ``Just`` is >= to the given value.
+        """
+        return self.value >= val
