@@ -6,6 +6,9 @@ import typing as t
 
 from typing_extensions import Literal
 
+from ._type_helpers import SupportsLessThan as _SupportsLessThan
+from ._type_helpers import SupportsGreaterOrEqual as _SupportsGreaterOrEqual
+
 if t.TYPE_CHECKING:  # pragma: no cover
     # pylint: disable=unused-import,invalid-name
     from ._maybe import Maybe
@@ -13,6 +16,7 @@ if t.TYPE_CHECKING:  # pragma: no cover
 _T = t.TypeVar('_T', covariant=True)
 _TT = t.TypeVar('_TT', covariant=True)
 _Y = t.TypeVar('_Y')
+_Z = t.TypeVar('_Z')
 
 
 class _Nothing(t.Generic[_T]):
@@ -50,6 +54,9 @@ class _Nothing(t.Generic[_T]):
     def or_default(self, value: _Y) -> _Y:
         return value
 
+    def or_none(self) -> t.Optional[_Y]:
+        return None
+
     def or_default_lazy(self, _producer: t.Callable[[], _Y]) -> _Y:
         return _producer()
 
@@ -81,6 +88,9 @@ class _Nothing(t.Generic[_T]):
     def __repr__(self) -> str:
         return 'Nothing'
 
+    def __structlog__(self) -> t.Mapping[str, object]:
+        return {'type': 'Nothing'}
+
     @classmethod
     def is_nothing_instance(cls, obj: object) -> bool:
         """Check if the given object is a Nothing object.
@@ -95,9 +105,45 @@ class _Nothing(t.Generic[_T]):
         """
         return isinstance(obj, cls)
 
-    def __bool__(self) -> t.NoReturn:
+    def __bool__(self) -> Literal[False]:
         raise Exception('Do not check Nothing for boolean value')
 
+    def attr(self, attr: str) -> object:  # pylint: disable=unused-argument
+        return Nothing
+
+    def join(self: '_Nothing[Maybe[_Y]]') -> '_Nothing[_Y]':
+        return Nothing
+
+    def eq(
+        self: '_Nothing[_Y]',
+        val: _Y,  # pylint: disable=unused-argument
+    ) -> Literal[False]:
+        return False
+
+    def lt(  # pylint: disable=invalid-name
+        self: '_Nothing[_SupportsLessThan[_T]]',
+        val: _SupportsLessThan[_T],  # pylint: disable=unused-argument
+    ) -> Literal[False]:
+        return False
+
+    def le(
+        self: '_Nothing[_SupportsGreaterOrEqual[_T]]',
+        val: _SupportsGreaterOrEqual[_T],  # pylint: disable=unused-argument
+    ) -> Literal[False]:
+        return False
+
+    def gt(  # pylint: disable=invalid-name
+        self: '_Nothing[_SupportsLessThan[_T]]',
+        val: _SupportsLessThan[_T],  # pylint: disable=unused-argument
+    ) -> Literal[False]:
+        return False
+
+    def ge(
+        self: '_Nothing[_SupportsGreaterOrEqual[_T]]',
+        val: _SupportsGreaterOrEqual[_T],  # pylint: disable=unused-argument
+    ) -> Literal[False]:
+        return False
+
     # pylint: enable=no-self-use,missing-function-docstring
 
 
