@@ -12,6 +12,7 @@ from .assignment_done_type import AssignmentDoneType
 from .assignment_feedback import AssignmentFeedback
 from .assignment_grader import AssignmentGrader
 from .assignment_kind import AssignmentKind
+from .assignment_login_link import AssignmentLoginLink
 from .assignment_peer_feedback_connection import (
     AssignmentPeerFeedbackConnection,
 )
@@ -21,6 +22,7 @@ from .auto_test import AutoTest
 from .auto_test_fixture import AutoTestFixture
 from .auto_test_quality_comment import AutoTestQualityComment
 from .auto_test_result import AutoTestResult
+from .auto_test_result_state import AutoTestResultState
 from .auto_test_run import AutoTestRun
 from .auto_test_set import AutoTestSet
 from .auto_test_step_base import AutoTestStepBase
