@@ -34,6 +34,9 @@ class Assignment:
     #: The deadline of the assignment. It is possible the assignment has no
     #: deadline yet, in which case it will be `None`.
     deadline: "Optional[datetime.datetime]"
+    #: The moment this assignment locks, this can be seen as a form of second
+    #: deadline.
+    lock_date: "Optional[datetime.datetime]"
     #: The name of the assignment.
     name: "str"
     #: Is this an LTI assignment.
@@ -139,6 +142,14 @@ class Assignment:
                     " `None`."
                 ),
             ),
+            rqa.RequiredArgument(
+                "lock_date",
+                rqa.Nullable(rqa.RichValue.DateTime),
+                doc=(
+                    "The moment this assignment locks, this can be seen as a"
+                    " form of second deadline."
+                ),
+            ),
             rqa.RequiredArgument(
                 "name",
                 rqa.SimpleValue.str,
@@ -337,6 +348,7 @@ class Assignment:
         res["description"] = to_dict(self.description)
         res["created_at"] = to_dict(self.created_at)
         res["deadline"] = to_dict(self.deadline)
+        res["lock_date"] = to_dict(self.lock_date)
         res["name"] = to_dict(self.name)
         res["is_lti"] = to_dict(self.is_lti)
         res["course_id"] = to_dict(self.course_id)
@@ -375,6 +387,7 @@ class Assignment:
             description=parsed.description,
             created_at=parsed.created_at,
             deadline=parsed.deadline,
+            lock_date=parsed.lock_date,
             name=parsed.name,
             is_lti=parsed.is_lti,
             course_id=parsed.course_id,
